gchecky.model.error_t

Package gchecky :: Module model :: Class error_t |
[hide private]
[frames] | no frames]

# Class error_t

source code

    object --+
             |
     gxml.Node --+
                 |
     gxml.Document --+
                     |
                    error_t

Represents a response containing information about an invalid API request. The information is intended to help you debug the problem causing the error.

    >>> test_document(
    ...     error_t(serial_number = '3c394432-8270-411b-9239-98c2c499f87f',
    ...             error_message='Bad username and/or password for API Access.',
    ...             warning_messages = ['IP address is suspicious.',
    ...                                 'MAC address is shadowed.']
    ...     )
    ... ,
    ... '''
    ... <error xmlns="http://checkout.google.com/schema/2" serial-number="3c394432-8270-411b-9239-98c2c499f87f">
    ...   <error-message>Bad username and/or password for API Access.</error-message>
    ...   <warning-messages>
    ...     <string>IP address is suspicious.</string>
    ...     <string>MAC address is shadowed.</string>
    ...   </warning-messages>
    ... </error>
    ... '''
    ... )

Nested Classes | [hide private]
Inherited from `gxml.Document`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Document`: `__str__`, `toxml` Inherited from `gxml.Node`: `__eq__`, `__init__`, `__neq__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `gxml.Document`: `fromxml` Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| tag_name = ``'``error``'`` The document's unique xml tag name.
| serial_number = `ID:PATH(@serial-number):REQ:EMPTY`
| error_message = `String:PATH(error-message):REQ:EMPTY`
| warning_messages = `List:PATH(warning-messages):OP`...``
| _fields = ``{``'``error_message``'``:` String:PATH(error-message):REQ:EMP`...`` list of meta-Fields of this class.

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### warning_messages Value:
      List:PATH(warning-messages):OPT:[
          String:PATH(string):REQ:EMPTY
      ]

  ### _fields list of meta-Fields of this class. Value:
      {'error_message': String:PATH(error-message):REQ:EMPTY,
       'serial_number': ID:PATH(@serial-number):REQ:EMPTY,
       'warning_messages': List:PATH(warning-messages):OPT:[
          String:PATH(string):REQ:EMPTY
      ]}